PqcAlgorithm

Enum PqcAlgorithm 

pub enum PqcAlgorithm {
Show 15 variants MlKem768X25519, MlKem1024X448, MlKem768P384, MlKem1024P521, MlKem768Bp384, MlKem1024Bp512, MlDsa65Ed25519, MlDsa87Ed448, MlDsa65P384, MlDsa87P521, MlDsa65Bp384, MlDsa87Bp512, SlhDsaShake128f, SlhDsaShake128s, SlhDsaShake256s,
}
PQC composite algorithms. Available only when the crate is built with --features pqc and the linked librnp was built with ENABLE_PQC=ON.

These wrap the RNP_ALGNAME_KYBER* / RNP_ALGNAME_DILITHIUM* / RNP_ALGNAME_SPHINCSPLUS_* string constants in rnp.h.

Variants



MlKem768X25519



MlKem1024X448



MlKem768P384



MlKem1024P521



MlKem768Bp384



MlKem1024Bp512



MlDsa65Ed25519



MlDsa87Ed448



MlDsa65P384



MlDsa87P521



MlDsa65Bp384



MlDsa87Bp512



SlhDsaShake128f



SlhDsaShake128s



SlhDsaShake256s

Implementations

Source

impl PqcAlgorithm

pub fn as_str(self) -> &'static str